import type { PluginCreator } from 'postcss';
declare type pluginOptions = {
    enableProgressiveCustomProperties?: boolean;
    preserve?: boolean;
    subFeatures?: {
        displayP3?: boolean;
    };
};
/** Transform oklab() and oklch() functions in CSS. */
declare const postcssPlugin: PluginCreator<pluginOptions>;
export default postcssPlugin;
